From e5360329c1342bee00369883706161537799f138 Mon Sep 17 00:00:00 2001
From: Daniel Gustafsson <dgustafsson@postgresql.org>
Date: Tue, 30 Aug 2022 12:50:14 +0200
Subject: [PATCH v3] pgcrypto: Remove unused code

The mbuf_tell, mbuf_rewind and pgp_get_cipher_name functions were
introduced in commit e94dd6ab91 but were never used, so remove.

Discussion: https://postgr.es/m/FCF3F14E-17D5-41F2-AC58-0A97B341193A@yesql.se
---
 contrib/pgcrypto/mbuf.c | 13 -------------
 contrib/pgcrypto/mbuf.h |  2 --
 contrib/pgcrypto/pgp.c  | 10 ----------
 contrib/pgcrypto/pgp.h  |  1 -
 4 files changed, 26 deletions(-)

diff --git a/contrib/pgcrypto/mbuf.c b/contrib/pgcrypto/mbuf.c
index bc668a0e80..99f8957b00 100644
--- a/contrib/pgcrypto/mbuf.c
+++ b/contrib/pgcrypto/mbuf.c
@@ -58,12 +58,6 @@ mbuf_size(MBuf *mbuf)
 	return mbuf->data_end - mbuf->data;
 }
 
-int
-mbuf_tell(MBuf *mbuf)
-{
-	return mbuf->read_pos - mbuf->data;
-}
-
 int
 mbuf_free(MBuf *mbuf)
 {
@@ -164,13 +158,6 @@ mbuf_grab(MBuf *mbuf, int len, uint8 **data_p)
 	return len;
 }
 
-int
-mbuf_rewind(MBuf *mbuf)
-{
-	mbuf->read_pos = mbuf->data;
-	return 0;
-}
-
 int
 mbuf_steal_data(MBuf *mbuf, uint8 **data_p)
 {
diff --git a/contrib/pgcrypto/mbuf.h b/contrib/pgcrypto/mbuf.h
index e6d754e869..adb18430b7 100644
--- a/contrib/pgcrypto/mbuf.h
+++ b/contrib/pgcrypto/mbuf.h
@@ -78,13 +78,11 @@ struct PullFilterOps
  */
 MBuf	   *mbuf_create(int len);
 MBuf	   *mbuf_create_from_data(uint8 *data, int len);
-int			mbuf_tell(MBuf *mbuf);
 int			mbuf_avail(MBuf *mbuf);
 int			mbuf_size(MBuf *mbuf);
 int			mbuf_grab(MBuf *mbuf, int len, uint8 **data_p);
 int			mbuf_steal_data(MBuf *mbuf, uint8 **data_p);
 int			mbuf_append(MBuf *dst, const uint8 *buf, int cnt);
-int			mbuf_rewind(MBuf *mbuf);
 int			mbuf_free(MBuf *mbuf);
 
 /*
diff --git a/contrib/pgcrypto/pgp.c b/contrib/pgcrypto/pgp.c
index 3e9c2fef9b..8a6a6c2adf 100644
--- a/contrib/pgcrypto/pgp.c
+++ b/contrib/pgcrypto/pgp.c
@@ -133,16 +133,6 @@ pgp_get_digest_name(int code)
 	return NULL;
 }
 
-const char *
-pgp_get_cipher_name(int code)
-{
-	const struct cipher_info *i = get_cipher_info(code);
-
-	if (i != NULL)
-		return i->name;
-	return NULL;
-}
-
 int
 pgp_get_cipher_key_size(int code)
 {
diff --git a/contrib/pgcrypto/pgp.h b/contrib/pgcrypto/pgp.h
index f338523b7a..805f01af5b 100644
--- a/contrib/pgcrypto/pgp.h
+++ b/contrib/pgcrypto/pgp.h
@@ -244,7 +244,6 @@ int			pgp_free(PGP_Context *ctx);
 int			pgp_get_digest_code(const char *name);
 int			pgp_get_cipher_code(const char *name);
 const char *pgp_get_digest_name(int code);
-const char *pgp_get_cipher_name(int code);
 
 int			pgp_set_cipher_algo(PGP_Context *ctx, const char *name);
 int			pgp_set_s2k_mode(PGP_Context *ctx, int type);
-- 
2.32.1 (Apple Git-133)

